import re

PYENV_LOAD_STATUS_KEY = 'PYENV_CONFIG_LOADED'

DOT_ENV_FILE = ".env"

LOCAL_CONFIG_FILE_PREFIX = "local"

ENVIRONMENT_VARIABLE_NAME = "ENVIRONMENT"

DEBUG_VARIABLE_NAME = "ENVIRONMENT"

DEBUG_VARIABLE_VALUE = False

REGEX_CONFIG_VARIABLE_SELECT_PATTERN = r"(\r\n|\r|\n|\s)*?([\w_]*)=(['\"])?([\w\d()\-:/*?=@.+!%$_#^&,]*)(['\"])?([\s\r\n]*)"

REGEX_CONFIG_VARIABLE_REPLACEMENT_PATTERN = r'\1\2=\3\2_VALUE\5\6'
